@@ -1,20 +1,11 @@
-# $Id: Stash.pm 1476 2006-10-16 20:41:50Z claco $
+# $Id: Stash.pm 1079 2006-01-19 02:04:42Z claco $
 package Handel::Checkout::Stash;
 use strict;
 use warnings;
 
-BEGIN {
-    use Handel::L10N qw/translate/;
-};
-
 sub new {
-    my ($class, $data) = @_;
-
-    throw Handel::Exception::Argument(
-        -details => translate('PARAM1_NOT_HASHREF')
-    ) if defined $data && ref($data) ne 'HASH'; ## no critic
-
-    my $self = bless $data || {}, $class;
+    my $class = shift;
+    my $self = bless {}, ref $class || $class;
 
     return $self;
 };
@@ -23,8 +14,6 @@ sub clear {
     my $self = shift;
 
     %{$self} = ();
-
-    return;
 };
 
 1;
@@ -37,10 +26,10 @@ Handel::Checkout::Stash - Basic storage for checkout plugins during processing
 =head1 SYNOPSIS
 
     use Handel::Checkout;
-    
+
     my $checkout = Handel::Checkout->new;
     $checkout->process;
-    
+
     # later in some plugin
     sub myhandler {
         my ($self, $ctx) = @_;
@@ -48,11 +37,11 @@ Handel::Checkout::Stash - Basic storage for checkout plugins during processing
         $ctx->stash->{'mystuff'};
         ...
     };
-    
+
     # later in some other plugin
     sub myhandler {
         my ($self, $ctx) = @_;
-    
+
         my $stuff = $ctx->stash->{'mystuff'};
         ...
     };
@@ -70,13 +59,13 @@ tell Handel::Checkout to use the new stash instead:
     use strict;
     use warnings;
     use base 'Handel::Checkout::Stash';
-    
+
     sub clear {};
-    
+
     ---
-    
+
     use Handel::Checkout;
-    
+
     my $co = Handel::Checkout->new({
         stash => MyApp::Stash->new
     });
@@ -85,14 +74,7 @@ tell Handel::Checkout to use the new stash instead:
 
 =head2 new
 
-=over
-
-=item Arguments: \%data
-
-=back
-
-Creates a new instance of Handel::Checkout::Stash. You can optionally pass a hash
-reference to new which will be blessed into the new stash instance.
+Creates a new instance of Handel::Checkout::Stash.
 
 =head1 METHODS
 
