@@ -1,11 +1,13 @@
-# $Id: Constants.pm 923 2005-11-15 02:59:22Z claco $
+# $Id: Constants.pm 1004 2005-12-08 04:50:16Z claco $
 package Handel::Constants;
 use strict;
 use warnings;
-use vars qw(@EXPORT_OK %EXPORT_TAGS);
+use vars qw(@EXPORT_OK %EXPORT_TAGS @CHECKOUT_ALL_PHASES);
+
 
 BEGIN {
     use base 'Exporter';
+    use Handel::L10N qw(translate);
 };
 
 use constant CART_MODE_APPEND  => 3;
@@ -32,11 +34,12 @@ use constant CHECKOUT_DEFAULT_PHASES   => [CHECKOUT_PHASE_VALIDATE,
                                            CHECKOUT_PHASE_AUTHORIZE,
                                            CHECKOUT_PHASE_FINALIZE,
                                            CHECKOUT_PHASE_DELIVER];
-use constant CHECKOUT_ALL_PHASES       => [CHECKOUT_PHASE_INITIALIZE,
-                                           CHECKOUT_PHASE_VALIDATE,
-                                           CHECKOUT_PHASE_AUTHORIZE,
-                                           CHECKOUT_PHASE_FINALIZE,
-                                           CHECKOUT_PHASE_DELIVER];
+
+@CHECKOUT_ALL_PHASES = (CHECKOUT_PHASE_INITIALIZE,
+                        CHECKOUT_PHASE_VALIDATE,
+                        CHECKOUT_PHASE_AUTHORIZE,
+                        CHECKOUT_PHASE_FINALIZE,
+                        CHECKOUT_PHASE_DELIVER);
 
 use constant CHECKOUT_STATUS_OK        => 1;
 use constant CHECKOUT_STATUS_ERROR     => 2;
@@ -102,6 +105,10 @@ use constant CHECKOUT_HANDLER_ERROR    => 4;
         )]
     );
 
+sub CHECKOUT_ALL_PHASES {
+        return \@CHECKOUT_ALL_PHASES;
+};
+
 sub str_to_const {
     my $str = shift;
 
