@@ -1,4 +1,4 @@
-# $Id: Second.pm 837 2005-09-19 22:56:39Z claco $
+# $Id: Second.pm 1059 2006-01-06 01:59:25Z claco $
 package Handel::OtherTestPlugins::Second;
 use strict;
 use warnings;
@@ -9,7 +9,7 @@ sub register {
     my ($self, $ctx) = @_;
 
     $self->{'register_called'}++;
-    $ctx->add_handler(CHECKOUT_PHASE_INITIALIZE, \&handler);
+    $ctx->add_handler(CHECKOUT_PHASE_INITIALIZE, \&handler, 2);
 };
 
 sub init {
@@ -38,4 +38,4 @@ sub handler {
     return CHECKOUT_HANDLER_OK;
 };
 
-1;
\ No newline at end of file
+1;
