@@ -1,10 +1,10 @@
-# $Id: Cart.pm 897 2005-10-06 01:36:16Z claco $
+# $Id: Cart.pm 1043 2005-12-24 03:40:20Z claco $
 package Handel::Subclassing::Cart;
 use strict;
 use warnings;
 use base 'Handel::Cart';
 
 __PACKAGE__->add_columns('custom');
-__PACKAGE__->item_class('Handel::Subclassing::Item');
+__PACKAGE__->item_class('Handel::Subclassing::CartItem');
 
 1;
