@@ -1,8 +1,8 @@
-# $Id: Checkout.pm 1409 2006-09-09 21:16:54Z claco $
+# $Id: Checkout.pm 1043 2005-12-24 03:40:20Z claco $
 package Handel::Subclassing::Checkout;
 use strict;
 use warnings;
-use base qw/Handel::Checkout/;
+use base 'Handel::Checkout';
 
 __PACKAGE__->order_class('Handel::Subclassing::Order');
 
