@@ -1,4 +1,4 @@
-# $Id: TestHelper.pm 837 2005-09-19 22:56:39Z claco $
+# $Id: TestHelper.pm 1064 2006-01-10 00:06:26Z claco $
 package Handel::TestHelper;
 use strict;
 use warnings;
@@ -15,6 +15,10 @@ sub executesql {
     return unless ($db || $sqlfile);
 
     my $dbh = DBI->connect($db);
+
+    $dbh->do('PRAGMA synchronous = OFF');
+    $dbh->do('PRAGMA temp_store = MEMORY');
+
     open SQL, "< $sqlfile";
     while (<SQL>) {
         $dbh->do($_);
@@ -47,6 +51,9 @@ sub preparetables {
     foreach my $group (@{$groups}) {
         return unless exists $tables{$group};
 
+        $dbh->do('PRAGMA synchronous = OFF');
+        $dbh->do('PRAGMA temp_store = MEMORY');
+
         my $data = $tables{$group};
         my ($count) = $dbh->selectrow_array("SELECT COUNT(*) FROM sqlite_master WHERE type='table' AND name='" . $data->{'exists'} . "'");
 
@@ -108,4 +115,4 @@ sub comp_to_file {
     return 0;
 };
 
-1;
\ No newline at end of file
+1;
