@@ -1,9 +1,9 @@
-# $Id: InitializeTotals.pm 1336 2006-07-15 03:54:43Z claco $
+# $Id: InitializeTotals.pm 837 2005-09-19 22:56:39Z claco $
 package Handel::TestPipeline::InitializeTotals;
 use strict;
 use warnings;
 use base 'Handel::Checkout::Plugin';
-use Handel::Constants qw(:checkout);
+use Handel::Constants qw(:checkout :returnas);
 
 sub register {
     my ($self, $ctx) = @_;
@@ -19,8 +19,8 @@ sub handler {
         my $subtotal = 0;
 
         eval {
-            my @items = $order->items;
-            foreach my $item (@items) {
+            my $items = $order->items(undef, RETURNAS_ITERATOR);
+            while (my $item = $items->next) {
                 $item->total($item->quantity*$item->price);
                 $subtotal += $item->total;
             };
@@ -40,4 +40,4 @@ sub handler {
     };
 };
 
-1;
+1;
\ No newline at end of file
